@@ -1,4 +1,4 @@
-/* $Id: netload.c,v 1.10 2003/10/19 16:54:17 carlos Exp $ */
+/* $Id: netload.c,v 1.12 2003/10/20 15:19:36 hadess Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -26,7 +26,6 @@
 #include <glibtop.h>
 #include <glibtop/open.h>
 #include <glibtop/close.h>
-#include <glibtop/xmalloc.h>
 
 #include <glibtop/parameter.h>
 
@@ -82,8 +81,8 @@ main (int argc, char *argv [])
 	addr.s_addr = netload.address;
 	subnet.s_addr = netload.subnet;
 
-	address_string = glibtop_strdup (inet_ntoa (addr));
-	subnet_string  = glibtop_strdup (inet_ntoa (subnet));
+	address_string = g_strdup (inet_ntoa (addr));
+	subnet_string  = g_strdup (inet_ntoa (subnet));
 
 	printf ("Network Load (0x%08lx):\n\n"
 		"\tInterface Flags:\t0x%08lx\n"
@@ -116,8 +115,8 @@ main (int argc, char *argv [])
 		(unsigned long) netload.errors_out,
 		(unsigned long) netload.errors_total);
 
-	glibtop_free (address_string);
-	glibtop_free (subnet_string);
+	g_free (address_string);
+	g_free (subnet_string);
 
 	glibtop_close ();
 
