@@ -1,4 +1,4 @@
-/* $Id: procmem.h,v 1.21 2003/10/20 15:19:39 hadess Exp $ */
+/* $Id: procmem.h,v 1.22 2003/10/20 20:11:58 hadess Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -44,7 +44,7 @@ typedef struct _glibtop_proc_mem	glibtop_proc_mem;
 
 struct _glibtop_proc_mem
 {
-	u_int64_t	flags,
+	guint64	flags,
 		size,		/* total # of pages of memory */
 		vsize,		/* number of pages of virtual memory ... */
 		resident,	/* number of resident set
