@@ -1,4 +1,4 @@
-/* $Id: proctime.h,v 1.24 2003/10/20 15:19:39 hadess Exp $ */
+/* $Id: proctime.h,v 1.25 2003/10/20 20:11:58 hadess Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -50,7 +50,7 @@ typedef struct _glibtop_proc_time	glibtop_proc_time;
 
 struct _glibtop_proc_time
 {
-	u_int64_t	flags,
+	guint64	flags,
 		start_time,	/* start time of process -- 
 				 * seconds since 1-1-70 */
 		rtime,		/* real time accumulated by process */
