@@ -8,7 +8,7 @@
 
 #include <glibtop/sysdeps.h>
 #include <glibtop/union.h>
-#include <libgnome/gnome-i18n.h>
+#include "libgtop-i18n.h"
 
 #include <glibtop/command.h>
 
