@@ -1,4 +1,4 @@
-/* $Id: write.c,v 1.13 2003/10/20 15:19:41 hadess Exp $ */
+/* $Id: write.c,v 1.15 2004/03/04 15:29:12 hadess Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -24,7 +24,7 @@
 #include <config.h>
 
 #include <glibtop/write.h>
-#include <libgnome/gnome-i18n.h>
+#include "libgtop-i18n.h"
 
 /* Writes some data to server. */
 
@@ -48,5 +48,5 @@ glibtop_write_l (glibtop *server, size_t size, void *buf)
 	}
 
 	if (ret < 0)
-		glibtop_error_io_r (server, _("write %d bytes"), size);
+		glibtop_error_io_r (server, ngettext ("write %d byte", "write %d bytes", size), size);
 }
