@@ -1,3 +1,5 @@
+/* $Id: msg_limits.c,v 1.2 2003/10/19 16:54:39 carlos Exp $ */
+
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
 
@@ -19,21 +21,20 @@
    Boston, MA 02111-1307, USA.
 */
 
-#include <config.h>
 #include <sys/msg.h>
 
 #include <glibtop.h>
 #include <glibtop/error.h>
 #include <glibtop/msg_limits.h>
 
-static const unsigned long _glibtop_sysdeps_msg_limits =
+static const unsigned long _glibtop_sysdeps_msg_limits = 
 (1 << GLIBTOP_IPC_MSGMAX) + (1 << GLIBTOP_IPC_MSGMNB) +
 (1 << GLIBTOP_IPC_MSGMNI) + (1 << GLIBTOP_IPC_MSGTQL);
 
 /* Init function. */
 
 void
-_glibtop_init_msg_limits_p (glibtop *server)
+glibtop_init_msg_limits_p (glibtop *server)
 {
 	off_t result;
 
