@@ -1,4 +1,4 @@
-/* $Id: proclist.c,v 1.1.2.1 2002/12/30 16:15:12 hadess Exp $ */
+/* $Id: proclist.c,v 1.4 2003/10/20 15:19:46 hadess Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -24,7 +24,6 @@
 #include <procinfo.h>
 
 #include <glibtop.h>
-#include <glibtop/xmalloc.h>
 #include <glibtop/proclist.h>
 
 static const unsigned long _glibtop_sysdeps_proclist = 
@@ -188,15 +187,15 @@ glibtop_get_proclist_s (glibtop *server, glibtop_proclist *buf,
 	
 		if (count >= BLOCK_COUNT)
 		{
-			/* The following call to glibtop_realloc will be
-			 * equivalent to glibtop_malloc () if `pids_chain' is
+			/* The following call to g_realloc will be
+			 * equivalent to g_malloc () if `pids_chain' is
 			 * NULL. We just calculate the new size and copy `pids'
 			 * to the beginning of the newly allocated block. */
 
 			new_size = pids_size + BLOCK_SIZE;
 
-			pids_chain = glibtop_realloc_r
-					(server, pids_chain, new_size);
+			pids_chain = g_realloc
+					(pids_chain, new_size);
 			memcpy (pids_chain + pids_offset, pids, BLOCK_SIZE);
 
 			pids_size = new_size;
@@ -221,14 +220,14 @@ glibtop_get_proclist_s (glibtop *server, glibtop_proclist *buf,
 
 	if (!count) return NULL;
 
-	/* The following call to glibtop_realloc will be equivalent to
-	 * glibtop_malloc if pids_chain is NULL. We just calculate the
+	/* The following call to g_realloc will be equivalent to
+	 * g_malloc if pids_chain is NULL. We just calculate the
 	 * new size and copy pids to the beginning of the newly allocated
 	 * block. */
 
 	new_size = pids_size + count * sizeof (unsigned);
 
-	pids_chain = glibtop_realloc_r (server, pids_chain, new_size);
+	pids_chain = g_realloc (pids_chain, new_size);
 
 	memcpy (pids_chain + pids_offset, pids, count * sizeof (unsigned));
 
