@@ -1,4 +1,4 @@
-/* $Id: cpu.c,v 1.31 2003/12/23 10:44:33 hadess Exp $ */
+/* $Id: cpu.c,v 1.33 2004/03/10 00:15:39 bdejean Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -80,6 +80,11 @@ glibtop_get_cpu_s (glibtop *server, glibtop_cpu *buf)
 	buf->sys  = strtoull (p, &p, 0);
 	buf->idle = strtoull (p, &p, 0);
 
+	/* 2.6 kernel */
+	buf->idle += strtoull(p, &p, 0); /* "iowait" */
+	buf->sys  += strtoull(p, &p, 0); /* "irq" */
+	buf->sys  += strtoull(p, &p, 0); /* "softirq" */	
+
 	total = buf->user;
 	total += buf->nice;
 	total += buf->sys;
@@ -99,6 +104,11 @@ glibtop_get_cpu_s (glibtop *server, glibtop_cpu *buf)
 		buf->xcpu_sys  [i] = strtoull (p, &p, 0);
 		buf->xcpu_idle [i] = strtoull (p, &p, 0);
 
+		/* 2.6 kernel */
+		buf->xcpu_idle [i]  += strtoull(p, &p, 0); /* "iowait" */
+		buf->xcpu_sys  [i]  += strtoull(p, &p, 0); /* "irq" */
+		buf->xcpu_sys  [i]  += strtoull(p, &p, 0); /* "softirq" */
+
 		total = buf->xcpu_user [i];
 		total += buf->xcpu_nice [i];
 		total += buf->xcpu_sys [i];
