@@ -1,4 +1,4 @@
-/* $Id: glibtop_machine.h,v 1.8 2003/10/19 16:55:39 carlos Exp $ */
+/* $Id: glibtop_machine.h,v 1.9 2003/10/20 15:19:56 hadess Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -28,7 +28,7 @@
 #include <fcntl.h>
 #include <ctype.h>
 
-BEGIN_LIBGTOP_DECLS
+G_BEGIN_DECLS
 
 #if _IN_LIBGTOP
 
@@ -53,6 +53,6 @@ struct _glibtop_machine
 	char	proc_status [BUFSIZ];
 };
 
-END_LIBGTOP_DECLS
+G_END_DECLS
 
 #endif
