@@ -1,4 +1,4 @@
-/* $Id: procsegment.c,v 1.20 2003/10/19 16:55:39 carlos Exp $ */
+/* $Id: procsegment.c,v 1.21 2003/12/23 10:44:33 hadess Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -87,9 +87,9 @@ glibtop_get_proc_segment_s (glibtop *server, glibtop_proc_segment *buf,
 
 	p = skip_multiple_token (p, 23);
 
-	buf->start_code = strtoul (p, &p, 0);
-	buf->end_code = strtoul (p, &p, 0);
-	buf->start_stack = strtoul (p, &p, 0);
+	buf->start_code  = strtoull (p, &p, 0);
+	buf->end_code    = strtoull (p, &p, 0);
+	buf->start_stack = strtoull (p, &p, 0);
 
 	buf->flags = _glibtop_sysdeps_proc_segment;
 
@@ -101,10 +101,10 @@ glibtop_get_proc_segment_s (glibtop *server, glibtop_proc_segment *buf,
 	/* This doesn't work very well due to a bug in the Linux kernel.
 	 * I'll submit a patch to the kernel mailing list soon. */
 
-	buf->text_rss = strtoul (p, &p, 0);
-	buf->shlib_rss = strtoul (p, &p, 0);
-	buf->data_rss = strtoul (p, &p, 0);
-	buf->dirty_size = strtoul (p, &p, 0);
+	buf->text_rss   = strtoull (p, &p, 0);
+	buf->shlib_rss  = strtoull (p, &p, 0);
+	buf->data_rss   = strtoull (p, &p, 0);
+	buf->dirty_size = strtoull (p, &p, 0);
 
 	buf->text_rss   <<= pageshift;
 	buf->shlib_rss  <<= pageshift;
