@@ -1,4 +1,4 @@
-/* $Id: msg_limits.c,v 1.8 2003/10/20 15:19:59 hadess Exp $ */
+/* $Id: msg_limits.c,v 1.9 2004/03/04 15:29:15 hadess Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -22,7 +22,7 @@
 */
 
 #include <glibtop/msg_limits.h>
-#include <libgnome/gnome-i18n.h>
+#include "libgtop-i18n.h"
 
 const char *glibtop_names_msg_limits [GLIBTOP_MAX_MSG_LIMITS] =
 {
