@@ -1,4 +1,4 @@
-/* $Id: procsegment.c,v 1.10 2003/10/20 15:19:59 hadess Exp $ */
+/* $Id: procsegment.c,v 1.11 2004/03/04 15:29:15 hadess Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -23,7 +23,7 @@
 
 #include <glibtop.h>
 #include <glibtop/procsegment.h>
-#include <libgnome/gnome-i18n.h>
+#include "libgtop-i18n.h"
 
 const char *glibtop_names_proc_segment [GLIBTOP_MAX_PROC_SEGMENT] =
 {
