@@ -1,4 +1,4 @@
-/* $Id: glibtop_machine.h,v 1.12 2003/10/19 16:55:46 carlos Exp $ */
+/* $Id: glibtop_machine.h,v 1.13 2003/10/20 15:20:08 hadess Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -36,7 +36,7 @@
 #include <kvm.h>
 #include <sys/sysinfo.h>
 
-BEGIN_LIBGTOP_DECLS
+G_BEGIN_DECLS
 
 typedef struct _glibtop_machine glibtop_machine;
 
@@ -73,6 +73,6 @@ struct _glibtop_machine
 #endif
 };
 
-END_LIBGTOP_DECLS
+G_END_DECLS
 
 #endif /* __GLIBTOP_MACHINE_H__ */
