@@ -1,4 +1,4 @@
-/* $Id: mem.c,v 1.3.2.1 2001/02/14 23:07:41 martin Exp $ */
+/* $Id: mem.c,v 1.13 2003/10/20 20:12:28 hadess Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -63,7 +63,7 @@ glibtop_get_mem_s (glibtop *server, glibtop_mem *buf)
 
     memset (buf, 0, sizeof (glibtop_mem));
 
-    buf->total = (u_int64_t)sysconf(_SC_PHYS_PAGES) << pagesize << 10;
+    buf->total = (guint64)sysconf(_SC_PHYS_PAGES) << pagesize << 10;
     buf->flags = _glibtop_sysdeps_mem_os_sysconf;
 
     if(!kc)
