@@ -1,4 +1,4 @@
-/* $Id: procmap.c,v 1.14 2003/10/19 16:55:46 carlos Exp $ */
+/* $Id: procmap.c,v 1.17 2004/03/09 23:02:04 hadess Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -24,7 +24,6 @@
 
 #include <glibtop.h>
 #include <glibtop/error.h>
-#include <glibtop/xmalloc.h>
 #include <glibtop/procmap.h>
 
 #include <errno.h>
@@ -121,8 +120,7 @@ glibtop_get_proc_map_s (glibtop *server, glibtop_proc_map *buf,	pid_t pid)
 		return NULL;
 	}
 #endif
-	if(!(entry = glibtop_malloc_r(server,
-		    		      nmaps * sizeof(glibtop_map_entry))))
+	if(!(entry = g_malloc(nmaps * sizeof(glibtop_map_entry))))
 	   	return NULL;
 	buf->number = nmaps;
 	buf->size = sizeof(glibtop_map_entry);
