@@ -1,4 +1,4 @@
-/* $Id: glibtop_machine.h,v 1.7 2003/10/19 16:55:51 carlos Exp $ */
+/* $Id: glibtop_machine.h,v 1.8 2003/10/20 15:20:15 hadess Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -24,7 +24,7 @@
 #ifndef __GLIBTOP_MACHINE_H__
 #define __GLIBTOP_MACHINE_H__
 
-BEGIN_LIBGTOP_DECLS
+G_BEGIN_DECLS
 
 typedef struct _glibtop_machine		glibtop_machine;
 
@@ -34,6 +34,6 @@ struct _glibtop_machine
 	gid_t gid, egid;		/* Real and effective group id */
 };
 
-END_LIBGTOP_DECLS
+G_END_DECLS
 
 #endif
