@@ -1,3 +1,5 @@
+/* $Id: prockernel.c,v 1.8 2003/10/19 16:55:51 carlos Exp $ */
+
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
 
@@ -19,7 +21,6 @@
    Boston, MA 02111-1307, USA.
 */
 
-#include <config.h>
 #include <glibtop.h>
 #include <glibtop/error.h>
 #include <glibtop/prockernel.h>
@@ -31,7 +32,7 @@ static const unsigned long _glibtop_sysdeps_proc_kernel = 0;
 /* Init function. */
 
 void
-_glibtop_init_proc_kernel_p (glibtop *server)
+glibtop_init_proc_kernel_p (glibtop *server)
 {
 	server->sysdeps.proc_kernel = _glibtop_sysdeps_proc_kernel;
 }
@@ -43,6 +44,6 @@ glibtop_get_proc_kernel_p (glibtop *server, glibtop_proc_kernel *buf,
 			   pid_t pid)
 {
 	glibtop_init_p (server, GLIBTOP_SYSDEPS_PROC_KERNEL, 0);
-
+	
 	memset (buf, 0, sizeof (glibtop_proc_kernel));
 }
